@@ -1,12 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2016-2021 Pytroll developers
+# Copyright (c) 2016-2022 Pytroll developers
 #
-# Author(s):
-#
-#   Adam.Dybbroe <adam.dybbroe@smhi.se>
-#   Martin Raspaud <martin.raspaud@smhi.se>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,9 +19,9 @@
 
 """Atmospheric correction of shortwave imager bands in the wavelength range 400 to 800 nm."""
 
-import os
 import logging
 import numbers
+import os
 
 import h5py
 import numpy as np
@@ -36,13 +32,19 @@ except ImportError:
     da = None
 
 from geotiepoints.multilinear import MultilinearInterpolator
-from pyspectral.rsr_reader import RelativeSpectralResponse
-from pyspectral.utils import (INSTRUMENTS, get_rayleigh_lut_dir,
-                              AEROSOL_TYPES, ATMOSPHERES,
-                              BANDNAMES,
-                              ATM_CORRECTION_LUT_VERSION,
-                              download_luts, get_central_wave)
+
 from pyspectral.config import get_config
+from pyspectral.rsr_reader import RelativeSpectralResponse
+from pyspectral.utils import (
+    AEROSOL_TYPES,
+    ATM_CORRECTION_LUT_VERSION,
+    ATMOSPHERES,
+    BANDNAMES,
+    INSTRUMENTS,
+    download_luts,
+    get_central_wave,
+    get_rayleigh_lut_dir,
+)
 
 LOG = logging.getLogger(__name__)
 
@@ -148,12 +150,16 @@ class Rayleigh(RayleighConfigBaseClass):
         self.sensor = sensor
         self.coeff_filename = None
 
-        # Try fix instrument naming
+        # Try to fix instrument naming
         instr = INSTRUMENTS.get(platform_name, sensor)
         if instr != sensor:
-            sensor = instr
-            LOG.warning("Inconsistent sensor/satellite input - " +
-                        "sensor set to %s", sensor)
+            if isinstance(instr, list):
+                if sensor not in instr:
+                    raise ValueError("This satellite has multiple sensors, you must explicitly state which to use.")
+            else:
+                sensor = instr
+                LOG.warning("Inconsistent sensor/satellite input - " +
+                            "sensor set to %s", sensor)
 
         self.sensor = sensor.replace('/', '')
 
@@ -267,7 +273,7 @@ class Rayleigh(RayleighConfigBaseClass):
                                              dtype=res.dtype,
                                              chunks=getattr(res, "chunks", None))
 
-        res = np.clip(np.nan_to_num(res), 0, 100)
+        res = np.clip(res, 0, 100)
         if compute:
             res = res.compute()
         return res
@@ -349,22 +355,23 @@ def get_reflectance_lut_from_file(lut_filename):
     return azidiff, satellite_zenith_secant, sun_zenith_secant
 
 
-def check_and_download(**kwargs):
-    """
-    Download atm correction LUT tables if they are not up to date already.
+def check_and_download(dry_run=False, aerosol_types=None):
+    """Download atm correction LUT tables if they are not up-to-date already.
 
     Do a check for the version of the atmospheric correction LUTs and attempt
     downloading only if needed.
 
     """
-    aerosol_types = kwargs.get('aerosol_types', AEROSOL_TYPES)
-    dry_run = kwargs.get('dry_run', False)
-
+    aerosol_types = aerosol_types or AEROSOL_TYPES
+    needed_aerosol_types = []
     for aerosol_type in aerosol_types:
         atmcorr = RayleighConfigBaseClass(aerosol_type)
         if atmcorr.lutfiles_version_uptodate:
             LOG.info("Atm correction LUTs, for aerosol distribution %s, already the latest!",
                      aerosol_type)
         else:
-            # Download
-            download_luts(aerosol_type=aerosol_type, dry_run=dry_run)
+            needed_aerosol_types.append(aerosol_type)
+
+    # Download
+    if needed_aerosol_types:
+        download_luts(aerosol_types=needed_aerosol_types, dry_run=dry_run)
