@@ -1,11 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2016-2019, 2021 Pytroll developers
+# Copyright (c) 2016-2022 Pytroll developers
 #
-# Author(s):
-#
-#   Adam.Dybbroe <a000680@c20671.ad.smhi.se>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,25 +20,29 @@
 """Unittest for the rayleigh correction utilities."""
 import contextlib
 import os
-import numpy as np
+import unittest
+from unittest.mock import patch
+
 import dask.array as da
 import h5py
+import numpy as np
 import pytest
-from pyspectral import rayleigh
-from pyspectral.tests.data import (
-    TEST_RAYLEIGH_LUT,
-    TEST_RAYLEIGH_AZID_COORD,
-    TEST_RAYLEIGH_SUNZ_COORD,
-    TEST_RAYLEIGH_SATZ_COORD,
-    TEST_RAYLEIGH_WVL_COORD)
-from pyspectral.utils import ATM_CORRECTION_LUT_VERSION
 
-from unittest.mock import patch
+from pyspectral import rayleigh, utils
+from pyspectral.tests.data import (
+    TEST_RAYLEIGH_AZID_COORD,
+    TEST_RAYLEIGH_LUT,
+    TEST_RAYLEIGH_SATZ_COORD,
+    TEST_RAYLEIGH_SUNZ_COORD,
+    TEST_RAYLEIGH_WVL_COORD,
+)
+from pyspectral.utils import ATM_CORRECTION_LUT_VERSION
 
 TEST_RAYLEIGH_RESULT1 = np.array([10.339923,    8.64748], dtype='float32')
 TEST_RAYLEIGH_RESULT2 = np.array([9.653559, 8.464997], dtype='float32')
 TEST_RAYLEIGH_RESULT3 = np.array([5.488735, 8.533125], dtype='float32')
 TEST_RAYLEIGH_RESULT4 = np.array([0.0,    8.64748], dtype='float32')
+TEST_RAYLEIGH_RESULT5 = np.array([9.653559, np.nan], dtype='float32')
 TEST_RAYLEIGH_RESULT_R1 = np.array([16.66666667, 20.83333333, 25.], dtype='float32')
 TEST_RAYLEIGH_RESULT_R2 = np.array([0., 6.25, 12.5], dtype='float32')
 
@@ -119,8 +120,8 @@ def _create_fake_lut_hdf5_file(base_dir, atm_type) -> str:
     return filename
 
 
-def _create_rayleigh():
-    rayl = rayleigh.Rayleigh('NOAA-20', 'viirs', atmosphere='midlatitude summer')
+def _create_rayleigh(platform='NOAA-20', sensor='VIIRS'):
+    rayl = rayleigh.Rayleigh(platform, sensor, atmosphere='midlatitude summer')
     return rayl
 
 
@@ -279,6 +280,24 @@ class TestRayleigh:
         retv = rayleigh.Rayleigh.reduce_rayleigh_highzenith(sun_zenith, in_rayleigh, 30., 90., 1.5)
         np.testing.assert_allclose(retv, TEST_RAYLEIGH_RESULT_R2)
 
+    def test_rayleigh_getname(self):
+        """Test logic for Rayleigh instrument selection."""
+
+        with pytest.raises(ValueError):
+            _create_rayleigh(platform='FY-4B')
+
+        rayl = _create_rayleigh(platform='FY-4A', sensor='agri')
+        assert rayl.sensor == 'agri'
+
+        rayl = _create_rayleigh(platform='FY-4B', sensor='agri')
+        assert rayl.sensor == 'agri'
+
+        rayl = _create_rayleigh(platform='FY-4B', sensor='ghi')
+        assert rayl.sensor == 'ghi'
+
+        with pytest.raises(ValueError):
+            _create_rayleigh(platform='FY-4B', sensor='nosensor')
+
     @patch('pyspectral.rayleigh.da', None)
     def test_get_reflectance_redband_outside_clip(self, fake_lut_hdf5):
         """Test getting the reflectance correction - using red band reflections outside 20 to 100."""
@@ -313,28 +332,25 @@ class TestRayleigh:
         np.testing.assert_allclose(refl_corr2, refl_corr3)
 
     @patch('pyspectral.rayleigh.da', None)
-    def test_get_reflectance(self, fake_lut_hdf5):
+    @pytest.mark.parametrize(
+        ("sun_zenith", "sat_zenith", "azidiff", "redband_refl", "exp_result"),
+        [
+            (np.array([67., 32.]), np.array([45., 18.]), np.array([150., 110.]), np.array([14., 5.]),
+             TEST_RAYLEIGH_RESULT1),
+            (np.array([60., 20.]), np.array([49., 26.]), np.array([140., 130.]), np.array([12., 8.]),
+             TEST_RAYLEIGH_RESULT2),
+            (np.array([60., 20.]), np.array([49., 26.]), np.array([140., 130.]), np.array([12., np.nan]),
+             TEST_RAYLEIGH_RESULT5),
+        ]
+    )
+    def test_get_reflectance(self, fake_lut_hdf5, sun_zenith, sat_zenith, azidiff, redband_refl, exp_result):
         """Test getting the reflectance correction."""
-        sun_zenith = np.array([67., 32.])
-        sat_zenith = np.array([45., 18.])
-        azidiff = np.array([150., 110.])
-        redband_refl = np.array([14., 5.])
         rayl = _create_rayleigh()
         with mocked_rsr():
             refl_corr = rayl.get_reflectance(
                 sun_zenith, sat_zenith, azidiff, 'ch3', redband_refl)
-        np.testing.assert_allclose(refl_corr, TEST_RAYLEIGH_RESULT1)
-
-        sun_zenith = np.array([60., 20.])
-        sat_zenith = np.array([49., 26.])
-        azidiff = np.array([140., 130.])
-        redband_refl = np.array([12., 8.])
-        with mocked_rsr():
-            refl_corr = rayl.get_reflectance(
-                sun_zenith, sat_zenith, azidiff, 'ch3', redband_refl)
-
         assert isinstance(refl_corr, np.ndarray)
-        np.testing.assert_allclose(refl_corr, TEST_RAYLEIGH_RESULT2)
+        np.testing.assert_allclose(refl_corr, exp_result)
 
     @patch('pyspectral.rayleigh.da', None)
     def test_get_reflectance_no_rsr(self, fake_lut_hdf5):
@@ -389,3 +405,50 @@ class TestRayleigh:
         # test LUT doesn't have a subartic_summer file
         with pytest.raises(IOError):
             rayleigh.Rayleigh('UFO', 'unknown', atmosphere='subarctic summer')
+
+
+@pytest.mark.parametrize(
+    ("version", "exp_download"),
+    [
+        (None, False),
+        ("v0.0.0", True),
+    ],
+)
+def test_check_and_download(tmp_path, version, exp_download):
+    """Test that check_and_download only downloads when necessary."""
+    from pyspectral.rayleigh import check_and_download
+    with _fake_lut_dir(tmp_path, version), unittest.mock.patch("pyspectral.rayleigh.download_luts") as download:
+        check_and_download()
+        if exp_download:
+            download.assert_called()
+        else:
+            download.assert_not_called()
+
+
+@contextlib.contextmanager
+def _fake_lut_dir(tmp_path, lut_version):
+    with _fake_get_config(tmp_path):
+        for aerosol_type in utils.AEROSOL_TYPES:
+            atype_version_fn = utils.ATM_CORRECTION_LUT_VERSION[aerosol_type]["filename"]
+            atype_version = utils.ATM_CORRECTION_LUT_VERSION[aerosol_type]["version"]
+            atype_subdir = tmp_path / aerosol_type
+            atype_subdir.mkdir()
+            version_filename = str(atype_subdir / atype_version_fn)
+            with open(version_filename, "w") as version_file:
+                version_file.write(lut_version or atype_version)
+        yield
+
+
+@contextlib.contextmanager
+def _fake_get_config(tmp_path):
+    def _get_config():
+        return {
+            "rayleigh_dir": str(tmp_path),
+            "rsr_dir": str(tmp_path),
+            "download_from_internet": True,
+        }
+    with unittest.mock.patch("pyspectral.rayleigh.get_config") as get_config, \
+            unittest.mock.patch("pyspectral.utils.get_config") as get_config2:
+        get_config.side_effect = _get_config
+        get_config2.side_effect = _get_config
+        yield
