@@ -1,11 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2016, 2017 Pytroll developers
+# Copyright (c) 2016-2022 Pytroll developers
 #
-# Author(s):
-#
-#   Adam.Dybbroe <adam.dybbroe@smhi.se>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,29 +17,29 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Interface to the original Envisat AATSR spectral response functions from
-ESA: http://envisat.esa.int/handbooks/aatsr/aux-files/consolidatedsrfs.xls
+"""Interface to the original Envisat AATSR spectral response functions.
+
+From ESA: http://envisat.esa.int/handbooks/aatsr/aux-files/consolidatedsrfs.xls
 
 """
-from xlrd import open_workbook
-import numpy as np
-
-from pyspectral.utils import convert2hdf5 as tohdf5
-from pyspectral.config import get_config
-
 import logging
+
+import numpy as np
+from xlrd import open_workbook
+
+from pyspectral.config import get_config
+from pyspectral.utils import convert2hdf5 as tohdf5
+
 LOG = logging.getLogger(__name__)
 
 AATSR_BAND_NAMES = ['ir12', 'ir11', 'ir37', 'v16', 'v870', 'v659', 'v555']
 
 
 class AatsrRSR(object):
-
-    """Class for Envisat AATSR RSR"""
+    """Class for Envisat AATSR RSR."""
 
     def __init__(self, bandname, platform_name='Envisat'):
-        """Read the aatsr relative spectral responses for all channels"""
-
+        """Read the aatsr relative spectral responses for all channels."""
         self.platform_name = platform_name
         self.instrument = 'aatsr'
         self.bandname = bandname
@@ -58,7 +55,7 @@ class AatsrRSR(object):
         self._load()
 
     def _load(self, filename=None):
-        """Read the AATSR rsr data"""
+        """Read the AATSR rsr data."""
         if not filename:
             filename = self.aatsr_path
 
@@ -78,10 +75,5 @@ class AatsrRSR(object):
                 self.rsr = {'wavelength': wvl, 'response': resp}
 
 
-def main():
-    """Main"""
-
-    tohdf5(AatsrRSR, 'Envisat', AATSR_BAND_NAMES)
-
 if __name__ == "__main__":
-    main()
+    tohdf5(AatsrRSR, 'Envisat', AATSR_BAND_NAMES)
